package com.yiring.app.web.dict;

import com.yiring.app.param.dict.DictParam;
import com.yiring.app.param.dict.DictQueryParam;
import com.yiring.app.param.dict.DictTypeParam;
import com.yiring.app.param.dict.DictTypeQueryParam;
import com.yiring.app.service.dict.DictService;
import com.yiring.app.service.dict.DictTypeService;
import com.yiring.common.core.Result;
import com.yiring.common.dict.Dict;
import com.yiring.common.dict.DictType;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.ArrayList;

/**
 * 字典类型控制器
 * @author tzl
 * 2022/4/14 15:14
 */
@Slf4j
@Validated
@Api(tags = "DictType")
@RestController
@RequestMapping("/DictType/")
public class DictTypeController {
    @Resource
    DictTypeService dictTypeService;

    @ApiOperation(value = "新增字典类型信息")
    @PostMapping("saveDictTypeInfo")
    public Result<String> saveDictTypeInfo(@Valid DictTypeParam dictTypeParam) {
        return dictTypeService.saveDictTypeInfo(dictTypeParam);
    }

    @ApiOperation(value = "修改字典类型信息")
    @PostMapping("updateDictTypeInfo")
    public Result<String> updateDictTypeInfo(@Valid DictTypeParam dictTypeParam, @Valid IdParam idParam) {
        return dictTypeService.updateDictTypeInfo(dictTypeParam, idParam);
    }


    @ApiOperation(value = "删除字典类型信息")
    @PostMapping("delecteById")
    public Result<String> delecteById(@Valid IdParam idParam) {
        return dictTypeService.delecteById(idParam.getId());
    }


    @ApiOperation(value = "查看字典类型信息(分页)")
    @GetMapping("pageDictTypeInfo")
    public Result<PageVo<DictType>> pageDictInfo(@Valid DictTypeQueryParam queryParam, @Valid PageParam param) {
        return dictTypeService.pageDictTypeInfo(queryParam, param);
    }

    @ApiOperation(value = "查看字典类型信息详情")
    @GetMapping("getDictTypeInfo")
    public Result<DictType> getDictTypeInfo(@Valid IdParam idParam) {
        return dictTypeService.getDictTypeInfo(idParam.getId());
    }
}
